pub trait EntityGraphExt<R: Runtime> {
// Required method
fn entity_graph(&self) -> &EntityGraph<R>;
}Expand description
Access the native platform bridge from a Tauri manager.
pub trait EntityGraphExt<R: Runtime> {
// Required method
fn entity_graph(&self) -> &EntityGraph<R>;
}Access the native platform bridge from a Tauri manager.