pub struct EntityChangedEvent {
pub entity_type: String,
pub entity_id: String,
pub operation: EntityOperation,
pub data: Option<JsonObject>,
}Expand description
Emitted when an entity is mutated on the Rust side (e.g. by an IPC command from another window, or a background task).
Fields
entity_type: Stringentity_id: Stringoperation: EntityOperationdata: Option<JsonObject>Trait Implementations
Sourceimpl Clone for EntityChangedEvent
impl Clone for EntityChangedEvent
Sourcefn clone(&self) -> EntityChangedEvent
fn clone(&self) -> EntityChangedEvent
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntityChangedEvent
impl Debug for EntityChangedEvent
Sourceimpl<'de> Deserialize<'de> for EntityChangedEvent
impl<'de> Deserialize<'de> for EntityChangedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more